/*
*  Name:      stack_value.hh
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   UESQL stack value for scanner/parser
*  Date:      $Date: 2000/02/16 13:34:05 $
*  Revision:  $Revision: 1.9 $
*
*  Copyright (C) 1996-1999  Rafael Jesus Alcantara Perez <rafa@dedalo-ing.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#ifndef _STACK_VALUE__
#define _STACK_VALUE__

#include <mpcl/string.hh>


///  Stack value for parser.
class TStackValue
{

  public:

    ///  True if <column definition> has been reduced to this non-terminal.
    bool            gHasColumnDefinition;

    ///  True if an <asterisk> has been reduced to this non-terminal.
    bool            gHasAsterisk;

    ///  Number of items (for parameter lists).
    int             iItemCount;

    ///  String with code generated.
    mpcl::xstring   yCode;

    ///  First identifier (in reverse order) in a composed identifier.
    mpcl::xstring   yFirstIdentifier;

    ///  Fourth identifier (in reverse order) in a composed identifier.
    mpcl::xstring   yFourthIdentifier;

    ///  String with original text.
    mpcl::xstring   yOriginalText;

    ///  Second identifier (in reverse order) in a composed identifier.
    mpcl::xstring   ySecondIdentifier;

    ///  Third identifier (in reverse order) in a composed identifier.
    mpcl::xstring   yThirdIdentifier;


  public:

    //
    //  C O N S T R U C T O R S
    //
 
    ///  Builds a new instance.
    TStackValue (void)             :
      gHasColumnDefinition (false) ,
      gHasAsterisk         (false) ,
      iItemCount           (-1)    ,
      yCode                ()      ,
      yFirstIdentifier     ()      ,
      yFourthIdentifier    ()      ,
      yOriginalText        ()      ,
      ySecondIdentifier    ()      ,
      yThirdIdentifier     ()      {}

};  // class TStackValue


#endif  // not _STACK_VALUE__
